CREATE SCHEMA Bauwerke

-- Historie:
-- 
-- 02.08.2006 - 1.011
-- Einfhrung OKSTRA-ID gem N0073
--
-- 09.09.2005 - 1.010 (1.010)
-- Anpassung an ASB-ING, Stand 2004
-- 
-- 29.06.2004 - 1.005 (1.009)
-- Verlegung der Kreuzungen in eigenes Schema
-- 
-- 03.09.2003 - 1.004 (1.008)
-- Korrektur von Whrungsangaben
-- 
-- 31.05.2002 - 1.003 (1.007)
-- berarbeitung gem Dokument N0031
-- 
-- 12.09.2001 - 1.002 (1.004)
-- nderung berlanger Bezeichner Strassenbaudienststelle_abstr
-- in Strassenbaudienstst_abstr (SQL)
-- 
-- 11.12.2000 - 1.001 (1.002)
-- Symbolische Verweise integriert fr
-- Teilbauwerk, Bauwerk, Strassenbaudienststelle
-- 
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Bauwerk (
   Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_ID) REFERENCES Bauwerk_abstrakt,
   FOREIGN KEY (Bauwerk_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauwerksnummer
      VARCHAR(7) NOT NULL,
   Interne_Bauwerksnummer
      VARCHAR(12),
   Interner_Sortierschluessel
      VARCHAR(15),
   Bauwerksname
      VARCHAR(50),
   naechstgelegener_Ort
      VARCHAR(50),
   Gesamtlaenge_Bruecken
      REAL, -- Meter
   Gesamtlaenge_Tunnel
      REAL, -- Meter
   Gesamtlaenge_Laermschutzbauw
      REAL, -- Meter
   Gesamtlaenge_Stuetzbauwerke
      REAL, -- Meter
   Bemerkungen
      VARCHAR(255),
   hat_Amt
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr,
   hat_Verwaltungsbezirk
      INTEGER REFERENCES Administration.Verwaltungsbezirk_abstrakt
)

CREATE TABLE Bauwerk__besteht_aus_Teilbauw (
   Bauwerk
      INTEGER NOT NULL REFERENCES Bauwerk,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bauwerk_abstrakt (
   Bauwerk_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Art_Bauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Art_Bauwerk_abstrakt
)

CREATE TABLE Art_Bauwerk_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(14) NOT NULL
)

INSERT INTO Art_Bauwerk_abstrakt VALUES ( 7001, 'Bauwerk' )
INSERT INTO Art_Bauwerk_abstrakt VALUES ( 7003, 'Bauwerk_Symbol' )

CREATE TABLE Bauwerk_Symbol (
   Bauwerk_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_Symbol_ID) REFERENCES Bauwerk_abstrakt,
   Kennung
      CHAR(7) NOT NULL
)

CREATE TABLE Teilbauwerk (
   Teilbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Teilbauwerk_abstrakt,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Strassennetz.Punktobjekt_hist,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   FOREIGN KEY (Teilbauwerk_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Teilbauwerksnummer
      VARCHAR(2) NOT NULL,
   Interne_Teilbauwerksnummer
      VARCHAR(2) NOT NULL,
   Name_des_Teilbauwerks
      VARCHAR(50),
   Interner_Sortierschluessel
      VARCHAR(15),
   Unterhaltung_Instandsetzung
      VARCHAR(15),
   Bauwerksart
      VARCHAR(15),
   Stadium_Teilbauwerk
      VARCHAR(15),
   Stationierung
      VARCHAR(15),
   Bauwerksakte_Nummer
      VARCHAR(50),
   Baulast_Konstruktion
      VARCHAR(15),
   Anderes_Bauwerk_nach_DIN1076
      VARCHAR(15),
   Baujahr
      INTEGER, -- Jahr
   Denkmalschutz
      VARCHAR(50),
   Unterlagen
      VARCHAR(255),
   Datenerfassung_abgeschlossen
      VARCHAR(15),
   Konstruktion
      VARCHAR(50),
   Bauwerksrichtung_Text
      VARCHAR(80),
   massgebendes_Teilbauwerk
      INTEGER REFERENCES Logical_Types.Boolean,
   Bemerkungen
      VARCHAR(255),
   hat_Strassenbaudienststelle
      INTEGER NOT NULL REFERENCES Administration.Strassenbaudienstst_abstr,
   hat_UI_Partner
      INTEGER REFERENCES Administration.UI_Partner,
   hat_Bauwerkseinzelheiten
      INTEGER NOT NULL REFERENCES Ingenieurbauwerke.Bauwerkseinzelheiten,
   gehoert_zu_Bauwerk
      INTEGER NOT NULL REFERENCES Bauwerk_abstrakt
)

CREATE TABLE Teilbauwerk__hat_Sachverhalt (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Teilbw__hat_abg_Prfg (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   abgeschlossene_Pruefung
      INTEGER NOT NULL REFERENCES abgeschlossene_Pruefung
)

CREATE TABLE Teilbw__hat_gw_dok_Bwzustand (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   gegenw_dokum_Bauwerkszustand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Bauwerkszustand
)

CREATE TABLE Teilbw__hat_durchgef_Prf_Mess (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   durchgef_Pruefungen_Messungen
      INTEGER NOT NULL REFERENCES durchgef_Pruefungen_Messungen
)

CREATE TABLE Teilbw__hat_Prueffz_Pruefger (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Prueffahrzeuge_Pruefgeraete
      INTEGER NOT NULL REFERENCES Prueffahrzeuge_Pruefgeraete
)

CREATE TABLE Teilbw__hat_Pruefanweisungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Pruefanweisungen
      INTEGER NOT NULL REFERENCES Pruefanweisungen
)

CREATE TABLE Teilbw__hat_Verwaltungsmassn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Verwaltungsmassn_Sondervereinb
      INTEGER NOT NULL REFERENCES Verwaltungsmassn_Sondervereinb
)

CREATE TABLE Teilbw__hat_Bau_u_Erhaltmassn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme
)

CREATE TABLE Teilbw__hat_Anlagen_Bauwbuch (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Anlagen_Bauwerksbuch
      INTEGER NOT NULL REFERENCES Anlagen_Bauwerksbuch
)

CREATE TABLE Teilbw__hat_Entwue_und_Berechn (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Entwuerfe_und_Berechnungen
      INTEGER NOT NULL REFERENCES Entwuerfe_und_Berechnungen
)

CREATE TABLE Teilbauwerk__hat_Gestaltungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Gestaltungen
      INTEGER NOT NULL REFERENCES Gestaltungen
)

CREATE TABLE Teilbw__hat_Leitungen_an_Bauw (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Leitungen_an_Bauwerken
      INTEGER NOT NULL REFERENCES Leitungen_an_Bauwerken
)

CREATE TABLE Teilbw__hat_stat_System_Tragf (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   statisches_System_Tragfaehigkt
      INTEGER NOT NULL REFERENCES statisches_System_Tragfaehigkt
)

CREATE TABLE Teilbauwerk__hat_Vorspannungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Vorspannungen
      INTEGER NOT NULL REFERENCES Vorspannungen
)

CREATE TABLE Teilbauwerk__hat_Gruendungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Gruendungen
      INTEGER NOT NULL REFERENCES Gruendungen
)

CREATE TABLE Teilbw__hat_Erd_und_Felsanker (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Erd_und_Felsanker
      INTEGER NOT NULL REFERENCES Erd_und_Felsanker
)

CREATE TABLE Teilbw__hat_Brueckseil_u_Kabel (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Brueckenseile_und_kabel
      INTEGER NOT NULL REFERENCES Brueckenseile_und_kabel
)

CREATE TABLE Teilbw__hat_Fahrbahnuebergang (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Fahrbahnuebergang
      INTEGER NOT NULL REFERENCES Fahrbahnuebergang
)

CREATE TABLE Teilbauwerk__hat_Abdichtungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Abdichtungen
      INTEGER NOT NULL REFERENCES Abdichtungen
)

CREATE TABLE Teilbauwerk__hat_Kappe (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Kappe
      INTEGER NOT NULL REFERENCES Kappe
)

CREATE TABLE Teilbw__hat_Schutzeinrichtgen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Schutzeinrichtungen
      INTEGER NOT NULL REFERENCES Schutzeinrichtungen
)

CREATE TABLE Teilbauwerk__hat_Ausstattung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Ausstattung
      INTEGER NOT NULL REFERENCES Ausstattung
)

CREATE TABLE Teilbauwerk__hat_Verfuellungen (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Verfuellungen
      INTEGER NOT NULL REFERENCES Verfuellungen
)

CREATE TABLE Teilbw__hat_Betonersatz (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Betonersatzsystem
      INTEGER NOT NULL REFERENCES Betonersatzsystem
)

CREATE TABLE Teilbw__hat_Oberflaechenschutz (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Oberflaechenschutzsystem
      INTEGER NOT NULL REFERENCES Oberflaechenschutzsystem
)

CREATE TABLE Teilbw__hat_Reaktharzg_Duennb (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Reaktionsharzgeb_Duennbelaege
      INTEGER NOT NULL REFERENCES Reaktionsharzgeb_Duennbelaege
)

CREATE TABLE Teilbauwerk__von_Hindernis (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Hindernis
      INTEGER NOT NULL REFERENCES Bauliche_Strasseneigenschaften.Hindernis
)

CREATE TABLE Teilbauwerk__von_Kreuzung (
   Teilbauwerk
      INTEGER NOT NULL REFERENCES Teilbauwerk,
   Kreuzung_Strasse_Weg
      INTEGER NOT NULL REFERENCES Kreuzungen.Kreuzung_Strasse_Weg
)

CREATE TABLE Teilbauwerk_abstrakt (
   Teilbauwerk_abstrakt_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Art_Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Art_Teilbauwerk_abstrakt
)

CREATE TABLE Art_Teilbauwerk_abstrakt (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(22) NOT NULL
)

INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7004, 'Teilbauwerk' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7006, 'Teilbauwerk_Symbol' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7014, 'Bruecke' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7015, 'Verkehrszeichenbruecke' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7016, 'Tunnel_Trogbauwerk' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7017, 'Laermschutzbauwerk' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7018, 'Stuetzbauwerk' )
INSERT INTO Art_Teilbauwerk_abstrakt VALUES ( 7019, 'sonstiges_Bauwerk' )

CREATE TABLE Teilbauwerk_Symbol (
   Teilbauwerk_Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Teilbauwerk_Symbol_ID) REFERENCES Teilbauwerk_abstrakt,
   Kennung
      CHAR(9) NOT NULL
)

CREATE TABLE Sachverhalt (
   Sachverhalt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Sachverhalt_ID) REFERENCES Strassennetz.Punktobjekt_stat,
   FOREIGN KEY (Sachverhalt_ID) REFERENCES Strassennetz.Streckenobjekt_stat,
   FOREIGN KEY (Sachverhalt_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Lage_Sachverhalt
      VARCHAR(15),
   Art_des_Sachverhaltes
      VARCHAR(15),
   Name_des_Sachverhaltes
      VARCHAR(80),
   Strassenklasse_des_Sachverh
      CHAR(1),
   Strassennummer_des_Sachverh
      INTEGER,
   Strassenzusatz
      VARCHAR(9),
   Abweichende_Zuordnung
      INTEGER REFERENCES Logical_Types.Boolean,
   Unterhaltungszuordnung
      INTEGER REFERENCES Logical_Types.Boolean,
   Verknuepfung_mit_Strassennetz
      INTEGER REFERENCES Logical_Types.Boolean,
   Bemerkungen
      VARCHAR(255),
   hat_Info_Strasse
      INTEGER REFERENCES Info_Strasse,
   hat_Bauwerk_Verkehrsstaerke
      INTEGER REFERENCES Bauwerk_Verkehrsstaerke,
   hat_Betriebskilometer
      INTEGER REFERENCES Strassennetz.Kilometrierung
)

CREATE TABLE Sachverhalt__von_Teilbauwerk (
   Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Info_Strasse (
   Info_Strasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Info_Strasse_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Nutzbare_Breite_in_Stat
      REAL, -- Meter
   Nutzbare_Breite_gegen_Stat
      REAL, -- Meter
   Min_Breite_in_Stationierung
      REAL, -- Meter
   Min_Breite_gegen_Stationierung
      REAL, -- Meter
   OD_FS
      CHAR(1) REFERENCES Administration.Tab_OD_FS,
   Abstand_von_Bestandsachse
      REAL, -- Meter
   Routing_1
      VARCHAR(50),
   Routing_2
      VARCHAR(50),
   Umfahrt_Schwerverkehr
      VARCHAR(15),
   Umfahrt_OePNV
      VARCHAR(15),
   Umfahrt_PKW
      VARCHAR(15),
   Bemerkung
      VARCHAR(255),
   hat_Amt
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr,
   hat_Meisterei
      INTEGER REFERENCES Administration.Strassenbaudienstst_abstr,
   hat_Anzahl_Fahrstreifen
      INTEGER REFERENCES Verkehr.Anzahl_Fahrstreifen,
   Baulasttraeger_Befestigung
      INTEGER REFERENCES Administration.UI_Partner,
   UI_Pflicht_Verkehrsflaeche
      INTEGER REFERENCES Administration.UI_Partner
)

CREATE TABLE Bauwerk_Verkehrsstaerke (
   Bauwerk_Verkehrsstaerke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerk_Verkehrsstaerke_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   zulaessige_Geschwindigkeit
      INTEGER, -- Stundenkilometer
   CHECK ( zulaessige_Geschwindigkeit >= 0 ),
   Bemerkung
      VARCHAR(255),
   DTV_Kfz
      INTEGER NOT NULL REFERENCES Verkehrsstaerke.DTV_Basis,
   Anteil_DTV_SV
      INTEGER REFERENCES Verkehrsstaerke.Anteil_am_DTV
)

CREATE TABLE Durchfahrtshoehen (
   Durchfahrtshoehen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Durchfahrtshoehen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Abstand_Bestandsachse
      REAL, -- Meter
   Durchfahrtshoehe
      REAL, -- Meter
   Kennzeichnung
      VARCHAR(15),
   Bemerkung
      VARCHAR(255),
   von_Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Bauwerksbeschilderung (
   Bauwerksbeschilderung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerksbeschilderung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Schild_StVO_Zeichennummer
      VARCHAR(10),
   Schild_Bezeichnung
      VARCHAR(50),
   Schild_Mengenangabe
      VARCHAR(50),
   Schild_Angabe_Zusatzschild
      VARCHAR(50),
   Bauwerksbeschild_Bemerkung
      VARCHAR(255),
   von_Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Bauwerksbelaege (
   Bauwerksbelaege_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bauwerksbelaege_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Art_der_Belaege
      VARCHAR(15),
   Deckschichtkennzeichnung
      INTEGER REFERENCES Logical_Types.Boolean,
   Belaege_Einbauort
      VARCHAR(255),
   Schichtnummer
      INTEGER,
   Schichtdicke
      REAL, -- Millimeter
   CHECK ( Schichtdicke >= 0 ),
   Einbaujahr
      INTEGER, -- Jahr
   Einbaumonat
      INTEGER, -- Monat
   CHECK ( ( Einbaumonat >= 1 ) AND ( Einbaumonat <= 12 ) ),
   Einbauflaeche
      REAL, -- Quadratmeter
   CHECK ( Einbauflaeche >= 0 ),
   ausfuehrende_Firma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255),
   von_Sachverhalt
      INTEGER NOT NULL REFERENCES Sachverhalt
)

CREATE TABLE Entwuerfe_und_Berechnungen (
   Entwuerfe_und_Berechnungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Entwuerfe_und_Berechnungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_Entw_und_Ber
      VARCHAR(15),
   Aufsteller_Entw_und_Ber
      VARCHAR(80),
   Bearbeiter_Entw_und_Ber
      VARCHAR(80),
   Aufstellungsjahr_Entw_und_Ber
      INTEGER, -- Jahr
   Bemerkungen_zu_Entw_und_Ber
      VARCHAR(255)
)

CREATE TABLE Bruecke (
   Bruecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bruecke_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge_Bruecke
      REAL, -- Meter
   Breite_Bruecke
      REAL, -- Meter
   Gesamtbreite_Bruecke
      REAL, -- Meter
   Brueckenflaeche
      REAL, -- Quadratmeter
   CHECK ( Brueckenflaeche >= 0 ),
   Zwischenraum_Ueberbauten
      REAL, -- Meter
   Konstruktionshoehe_min
      REAL, -- Meter
   Konstruktionshoehe_max
      REAL, -- Meter
   Anzahl_Felder_Bruecke
      INTEGER,
   Anzahl_Ueberbauten_Bruecke
      INTEGER,
   Anzahl_Stege_Bruecke
      INTEGER,
   Laengsneigung_max
      REAL, -- Prozent
   Querneigung_max
      REAL, -- Prozent
   Kruemmung
      VARCHAR(15),
   Bauwerkswinkel
      REAL, -- Gon
   CHECK ( Bauwerkswinkel >= 0 ),
   Winkelrichtung
      VARCHAR(15),
   Querschnitt_Ueberbau
      VARCHAR(15),
   Querschnitt_Haupttragwerk
      VARCHAR(15),
   Bauverfahren_Ueberbau
      VARCHAR(15),
   Konstr_Massn_nachtr_Verstaerk
      VARCHAR(15),
   Koppelfugen
      VARCHAR(15),
   maximale_Ueberschuettungshoehe
      REAL, -- Meter
   minimale_Ueberschuettungshoehe
      REAL, -- Meter
   lichte_Hoehe
      REAL, -- Meter
   lichte_Weite_b_Einfeldbruecke
      REAL, -- Meter
   Bemerkungen_zum_Baugrund
      VARCHAR(255),
   Bemerkungen_zur_Bruecke
      VARCHAR(255)
)

CREATE TABLE Bruecke__hat_Baustoff_Bauwerk (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Baustoff_Bauwerk
      INTEGER NOT NULL REFERENCES Baustoff_Bauwerk
)

CREATE TABLE Bruecke__hat_Brueckenf_Stuetz (
   Bruecke
      INTEGER NOT NULL REFERENCES Bruecke,
   Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Verkehrszeichenbruecke (
   Verkehrszeichenbruecke_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verkehrszeichenbruecke_ID) REFERENCES Teilbauwerk,
   Querschnitt_Stiel
      VARCHAR(15),
   Querschnitt_Riegel
      VARCHAR(15),
   Gesamtlaenge_des_Riegels
      REAL, -- Meter
   Besichtigungs_Wartungsoeffnung
      VARCHAR(15),
   Befest_Konstr_Schilder_Signalg
      VARCHAR(15),
   Bemerkung_Verkehrsz_Bruecke
      VARCHAR(255)
)

CREATE TABLE Verkzbr__hat_Baustoff_Bauwerk (
   Verkehrszeichenbruecke
      INTEGER NOT NULL REFERENCES Verkehrszeichenbruecke,
   Baustoff_Bauwerk
      INTEGER NOT NULL REFERENCES Baustoff_Bauwerk
)

CREATE TABLE Verkzeichenbr__hat_Bruefeld_St (
   Verkehrszeichenbruecke
      INTEGER NOT NULL REFERENCES Verkehrszeichenbruecke,
   Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Tunnel_Trogbauwerk (
   Tunnel_Trogbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnel_Trogbauwerk_ID) REFERENCES Teilbauwerk,
   Gradiente
      VARCHAR(15),
   Rundungshalbmesser
      REAL, -- Meter
   minimale_Laengsneigung
      REAL, -- Prozent
   maximale_Laengsneigung
      REAL, -- Prozent
   minimaler_Radius_im_Grundriss
      REAL, -- Meter
   minimale_Ueberdeckungshoehe
      REAL, -- Meter
   maximale_Ueberdeckungshoehe
      REAL, -- Meter
   Hoehe_rel_NN_in_Tunnelmitte
      REAL, -- Meter
   Bauwerkslaenge
      REAL, -- Meter
   geschl_Laenge_der_Tunnelroehre
      REAL, -- Meter
   Tunnelflaeche
      REAL, -- Quadratmeter
   CHECK ( Tunnelflaeche >= 0 ),
   Bauweise
      VARCHAR(15),
   Querschnitt
      VARCHAR(15),
   Lichte_Weite_Sonderquerschnitt
      REAL, -- Meter
   Ausbruchflaeche
      REAL, -- Quadratmeter
   CHECK ( Ausbruchflaeche >= 0 ),
   Sicherung
      VARCHAR(255),
   Geologie
      VARCHAR(15),
   Grund_und_Gebirgswasserverh
      VARCHAR(255),
   Bauverfahren
      VARCHAR(15),
   Vortriebsverfahren
      VARCHAR(15),
   Entwaesserungsart
      VARCHAR(15),
   Entwaesserungsart_Laenge
      VARCHAR(255),
   Bemerkungen_zum_Tunnel_Trogbau
      VARCHAR(255)
)

CREATE TABLE Tunnel_Trogbw__hat_Segmente (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Segment_Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Segment_Tunnel_Trogbauwerk
)

CREATE TABLE Tunnel_Trogbw__hat_Tunbeleucht (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnelbeleuchtung
      INTEGER NOT NULL REFERENCES Tunnelbeleuchtung
)

CREATE TABLE Tunnel_Trogbw__hat_Tunnellueft (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnellueftung
      INTEGER NOT NULL REFERENCES Tunnellueftung
)

CREATE TABLE Tunnel_Trogbw__hat_Zentr_Anl (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnel_Zentrale_Anlagen
      INTEGER NOT NULL REFERENCES Tunnel_Zentrale_Anlagen
)

CREATE TABLE Tunnel_Trogbw__hat_Tunsicherh (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnelsicherheit
      INTEGER NOT NULL REFERENCES Tunnelsicherheit
)

CREATE TABLE Tunnel_Trogbw__hat_Tunverkeinr (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Tunnel_Verkehrseinrichtungen
      INTEGER NOT NULL REFERENCES Tunnel_Verkehrseinrichtungen
)

CREATE TABLE Tunnel_Trogbw__hat_Baustoff_Bw (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Baustoff_Bauwerk
      INTEGER NOT NULL REFERENCES Baustoff_Bauwerk
)

CREATE TABLE Tunnel_Trogbw__hat_Brfeld_Stz (
   Tunnel_Trogbauwerk
      INTEGER NOT NULL REFERENCES Tunnel_Trogbauwerk,
   Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Laermschutzbauwerk (
   Laermschutzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laermschutzbauwerk_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge
      REAL, -- Meter
   Flaeche_des_Laermschirmes
      REAL, -- Quadratmeter
   CHECK ( Flaeche_des_Laermschirmes >= 0 ),
   Bemerkungen_zum_Laermschutzbw
      VARCHAR(255)
)

CREATE TABLE Laermschbw__hat_Segmente (
   Laermschutzbauwerk
      INTEGER NOT NULL REFERENCES Laermschutzbauwerk,
   Segment_Laermschutzbauwerk
      INTEGER NOT NULL REFERENCES Segment_Laermschutzbauwerk
)

CREATE TABLE Stuetzbauwerk (
   Stuetzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Stuetzbauwerk_ID) REFERENCES Teilbauwerk,
   Gesamtlaenge_Stuetzbauwerk
      REAL, -- Meter
   Flaeche_Stuetzbauwerk
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Stuetzbauwerk >= 0 ),
   Bemerkungen_zum_Stuetzbauwerk
      VARCHAR(255)
)

CREATE TABLE Stuetzbauwerk__hat_Segmente (
   Stuetzbauwerk
      INTEGER NOT NULL REFERENCES Stuetzbauwerk,
   Segment_Stuetzbauwerk
      INTEGER NOT NULL REFERENCES Segment_Stuetzbauwerk
)

CREATE TABLE sonstiges_Bauwerk (
   sonstiges_Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (sonstiges_Bauwerk_ID) REFERENCES Teilbauwerk,
   Stuetzweite_sonstiges_Bauwerk
      REAL, -- Meter
   Beschreibung_sonstiges_Bauwerk
      VARCHAR(255)
)

CREATE TABLE sonstiges_Bw__hat_Baustoff_Bw (
   sonstiges_Bauwerk
      INTEGER NOT NULL REFERENCES sonstiges_Bauwerk,
   Baustoff_Bauwerk
      INTEGER NOT NULL REFERENCES Baustoff_Bauwerk
)

CREATE TABLE Brueckenfeld_Stuetzung (
   Brueckenfeld_Stuetzung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Brueckenfeld_Stuetzung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Art_der_Stuetzung
      VARCHAR(15),
   Feldnummer
      INTEGER,
   Stuetzweite
      REAL, -- Meter
   Stuetzungshoehe
      REAL, -- Meter
   Anzahl_d_Stuetzen_einer_Reihe
      INTEGER,
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Segment_Tunnel_Trogbauwerk (
   Segment_Tunnel_Trogbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Segment_Tunnel_Trogbauwerk_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Segmentnummer
      INTEGER NOT NULL,
   Segmentlaenge
      REAL, -- Meter
   Oberflaeche_Tunneldecke
      VARCHAR(15),
   Oberflaeche_Tunnelwaende
      VARCHAR(15),
   Hoehe_Segmentanfang_rechts
      REAL, -- Meter
   Hoehe_Segmentanfang_links
      REAL, -- Meter
   Hoehe_Segmentende_rechts
      REAL, -- Meter
   Hoehe_Segmentende_links
      REAL, -- Meter
   Bemerkungen_Segm_Tunnel_Trogbw
      VARCHAR(255)
)

CREATE TABLE Segment_Laermschutzbauwerk (
   Segment_Laermschutzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Segment_Laermschutzbauwerk_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Segmentnummer
      INTEGER NOT NULL,
   Segmentlaenge_Laermschutz
      REAL, -- Meter
   Hoehe_Segmentanfang
      REAL, -- Meter
   Hoehe_Segmentende
      REAL, -- Meter
   Pfostenabstand
      REAL, -- Meter
   Standort_des_Pfostens
      VARCHAR(15),
   Untergrund
      VARCHAR(15),
   Fangvorrichtung
      VARCHAR(15),
   Vogelschutz
      VARCHAR(15),
   akustische_Eig_Vorsatzschale
      VARCHAR(15),
   Pflanzungen_Verkehrsseite
      VARCHAR(15),
   Pflanzungen_Anliegerseite
      VARCHAR(15),
   Besichtigungsweg_Anliegerseite
      VARCHAR(15),
   Bemerkungen_Laermschutz
      VARCHAR(255)
)

CREATE TABLE Segment_Stuetzbauwerk (
   Segment_Stuetzbauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Segment_Stuetzbauwerk_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Segmentnummer
      INTEGER NOT NULL,
   Segmentlaenge_Stuetzbauwerk
      REAL, -- Meter
   Hoehe_Segmentanfang_Stuetzbw
      REAL, -- Meter
   Hoehe_Segmentende_Stuetzbw
      REAL, -- Meter
   Besichtigungsweg_Anliegerseite
      VARCHAR(15),
   Bemerkungen_zum_Stuetzbauwerk
      VARCHAR(255)
)

CREATE TABLE Pruefanweisungen (
   Pruefanweisungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Pruefanweisungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   abweichende_Pruefpflicht
      VARCHAR(15),
   Pruefanweisungen
      VARCHAR(255),
   Tauchereinsatz
      VARCHAR(15),
   Pruefung_elektr_Einrichtungen
      VARCHAR(15),
   Pruefung_maschn_Einrichtungen
      VARCHAR(15),
   Bemerkungen_zur_Pruefanweisung
      VARCHAR(255)
)

CREATE TABLE durchgef_Pruefungen_Messungen (
   durchgef_Pruefungn_Messungn_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (durchgef_Pruefungn_Messungn_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Art_der_Pruefung
      VARCHAR(15),
   Pruefungs_Messungsdatum
      CHAR(10), -- Datum
   CHECK ( Pruefungs_Messungsdatum LIKE '__.__.____' ),
   Pruefungs_Messungszyklus
      INTEGER,
   Zustandsnote
      REAL,
   Bemerkungen_zur_durchgef_Prfg
      VARCHAR(255)
)

CREATE TABLE gegenw_dokum_Schaden (
   gegenw_dokum_Schaden_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (gegenw_dokum_Schaden_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Laufende_Nummer
      INTEGER NOT NULL,
   Menge_allgemein
      VARCHAR(9),
   Menge_mit_Dimension_Schluessel
      VARCHAR(9),
   Menge_mit_Dimension
      VARCHAR(20),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(9),
   Ortsbest_Feld_Pfeiler_Block_W
      VARCHAR(20),
   Ortsbestimmung_Ueberbau
      VARCHAR(9),
   Ortsbestimmung_Ueberbau_Werte
      VARCHAR(20),
   Ortsbest_laengs_Schluessel
      VARCHAR(9),
   Ortsbestimmung_laengs_Werte
      VARCHAR(20),
   Ortsbestimmung_quer
      VARCHAR(9),
   Ortsbestimmung_quer_Werte
      VARCHAR(20),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(9),
   Ortsbestimmung_hoch_Werte
      VARCHAR(20),
   Bewertung_Standsicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Bewertung_Standsicherheit >= 0  ) AND ( Bewertung_Standsicherheit <= 4 ) ),
   Bewertung_Verkehrssicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Bewertung_Verkehrssicherheit >= 0  ) AND ( Bewertung_Verkehrssicherheit <= 4 ) ),
   Bewertung_Dauerhaftigkeit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Bewertung_Dauerhaftigkeit >= 0  ) AND ( Bewertung_Dauerhaftigkeit <= 4 ) ),
   Schadensveraenderungen
      VARCHAR(9),
   Bemerkung_Schluessel_1
      VARCHAR(9),
   Bemerkung_Schluessel_2
      VARCHAR(9),
   Bemerkung_Schluessel_3
      VARCHAR(9),
   Bemerkung_Schluessel_4
      VARCHAR(9),
   Bemerkung_Schluessel_5
      VARCHAR(9),
   Bemerkung_Schluessel_6
      VARCHAR(9),
   Bemerkung_Text_1
      VARCHAR(20),
   Bemerkung_Text_2
      VARCHAR(20),
   Bemerkung_Text_3
      VARCHAR(20),
   Bemerkung_Text_4
      VARCHAR(20),
   Bemerkung_Text_5
      VARCHAR(20),
   Bemerkung_Text_6
      VARCHAR(20),
   Hauptbauteil
      VARCHAR(9),
   Konstruktionsteil
      VARCHAR(9),
   Bauteilergaenzung
      VARCHAR(9),
   Schaden
      VARCHAR(9),
   Schaden_Werte
      VARCHAR(20),
   Schadenstext
      VARCHAR(255),
   Name_Schadensbild
      VARCHAR(128),
   Pruefjahr_Ersterfassung
      INTEGER, -- Jahr
   Pruefart_Ersterfassung
      VARCHAR(2),
   Pruefjahr_letzte_Bestaetigung
      INTEGER, -- Jahr
   Pruefart_letzte_Bestaetigung
      VARCHAR(2),
   Vormerkung_einfache_Pruefung
      INTEGER REFERENCES Logical_Types.Boolean,
   ID_Nummer_des_Schadens
      VARCHAR(6),
   Schadensbeispiel_Nummer
      VARCHAR(10),
   Historisierungskennzeichen
      CHAR(1),
   von_gegenw_dok_Bauwerkszustand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Bauwerkszustand
)

CREATE TABLE gegenw_dokum_Bauwerkszustand (
   gegenw_dok_Bauwerkszustand_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (gegenw_dok_Bauwerkszustand_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Zustandsnote
      REAL,
   Max_Schadbw_Standsicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Max_Schadbw_Standsicherheit >= 0  ) AND ( Max_Schadbw_Standsicherheit <= 4 ) ),
   Max_Schadbw_Verkehrssicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Max_Schadbw_Verkehrssicherheit >= 0  ) AND ( Max_Schadbw_Verkehrssicherheit <= 4 ) ),
   Max_Schadbw_Dauerhaftigkeit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Max_Schadbw_Dauerhaftigkeit >= 0  ) AND ( Max_Schadbw_Dauerhaftigkeit <= 4 ) ),
   Datum_naechste_Hauptpruefung
      CHAR(10), -- Datum
   CHECK ( Datum_naechste_Hauptpruefung LIKE '__.__.____' ),
   Art_naechste_Hauptpruefung
      VARCHAR(2),
   Datum_naechste_einf_Pruefung
      CHAR(10), -- Datum
   CHECK ( Datum_naechste_einf_Pruefung LIKE '__.__.____' ),
   Datum_naechste_Sonderpruefung
      CHAR(10), -- Datum
   CHECK ( Datum_naechste_Sonderpruefung LIKE '__.__.____' ),
   Zustandstext
      VARCHAR(255),
   ZN_BTG_Ueberbau
      REAL,
   ZN_BTG_Unterbau
      REAL,
   ZN_BTG_Bauwerk
      REAL,
   ZN_BTG_Vorspannung
      REAL,
   ZN_BTG_Gruendungen
      REAL,
   ZN_BTG_Erd_und_Felsanker
      REAL,
   ZN_BTG_Brueckenseile
      REAL,
   ZN_BTG_Lager
      REAL,
   ZN_BTG_Uebergaenge
      REAL,
   ZN_BTG_Abdichtungen
      REAL,
   ZN_BTG_Belaege
      REAL,
   ZN_BTG_Kappen
      REAL,
   ZN_BTG_Schutzeinrichtg
      REAL,
   ZN_BTG_Sonstiges
      REAL
)

CREATE TABLE Schaden_abgeschl_Prfg (
   Schaden_abgeschl_Prfg_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schaden_abgeschl_Prfg_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Laufende_Nummer
      INTEGER NOT NULL,
   Menge_allgemein
      VARCHAR(9),
   Menge_mit_Dimension_Schluessel
      VARCHAR(9),
   Menge_mit_Dimension
      VARCHAR(20),
   Ortsbest_Feld_Pfeiler_Block
      VARCHAR(9),
   Ortsbest_Feld_Pfeiler_Block_W
      VARCHAR(20),
   Ortsbestimmung_Ueberbau
      VARCHAR(9),
   Ortsbestimmung_Ueberbau_Werte
      VARCHAR(20),
   Ortsbest_laengs_Schluessel
      VARCHAR(9),
   Ortsbestimmung_laengs_Werte
      VARCHAR(20),
   Ortsbestimmung_quer
      VARCHAR(9),
   Ortsbestimmung_quer_Werte
      VARCHAR(20),
   Ortsbestimmung_hoch_Schluessel
      VARCHAR(9),
   Ortsbestimmung_hoch_Werte
      VARCHAR(20),
   Bewertung_Standsicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Bewertung_Standsicherheit >= 0  ) AND ( Bewertung_Standsicherheit <= 4 ) ),
   Bewertung_Verkehrssicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Bewertung_Verkehrssicherheit >= 0  ) AND ( Bewertung_Verkehrssicherheit <= 4 ) ),
   Bewertung_Dauerhaftigkeit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Bewertung_Dauerhaftigkeit >= 0  ) AND ( Bewertung_Dauerhaftigkeit <= 4 ) ),
   Schadensveraenderungen
      VARCHAR(9),
   Bemerkung_Schluessel_1
      VARCHAR(9),
   Bemerkung_Schluessel_2
      VARCHAR(9),
   Bemerkung_Schluessel_3
      VARCHAR(9),
   Bemerkung_Schluessel_4
      VARCHAR(9),
   Bemerkung_Schluessel_5
      VARCHAR(9),
   Bemerkung_Schluessel_6
      VARCHAR(9),
   Bemerkung_Text_1
      VARCHAR(20),
   Bemerkung_Text_2
      VARCHAR(20),
   Bemerkung_Text_3
      VARCHAR(20),
   Bemerkung_Text_4
      VARCHAR(20),
   Bemerkung_Text_5
      VARCHAR(20),
   Bemerkung_Text_6
      VARCHAR(20),
   Hauptbauteil
      VARCHAR(9),
   Konstruktionsteil
      VARCHAR(9),
   Bauteilergaenzung
      VARCHAR(9),
   Schaden
      VARCHAR(9),
   Schaden_Werte
      VARCHAR(20),
   Schadenstext
      VARCHAR(255),
   Name_Schadensbild
      VARCHAR(128),
   Pruefjahr
      INTEGER, -- Jahr
   Pruefart
      VARCHAR(2),
   Vormerkung_einfache_Pruefung
      INTEGER REFERENCES Logical_Types.Boolean,
   ID_Nummer_des_Schadens
      VARCHAR(6),
   Schadensbeispiel_Nummer
      VARCHAR(10),
   von_abgeschlossene_Pruefung
      INTEGER NOT NULL REFERENCES abgeschlossene_Pruefung
)

CREATE TABLE abgeschlossene_Pruefung (
   abgeschlossene_Pruefung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (abgeschlossene_Pruefung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Pruefjahr
      INTEGER, -- Jahr
   Pruefart
      VARCHAR(2),
   Pruefrichtung
      VARCHAR(80),
   Pruefer
      VARCHAR(30),
   Dienstelle_Pruefer
      VARCHAR(30),
   Pruefungsbeginn
      CHAR(10), -- Datum
   CHECK ( Pruefungsbeginn LIKE '__.__.____' ),
   Abschluss_Schadenerfassung
      CHAR(10), -- Datum
   CHECK ( Abschluss_Schadenerfassung LIKE '__.__.____' ),
   Pruefungsabschluss
      CHAR(10), -- Datum
   CHECK ( Pruefungsabschluss LIKE '__.__.____' ),
   Max_Schadbw_Standsicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Max_Schadbw_Standsicherheit >= 0  ) AND ( Max_Schadbw_Standsicherheit <= 4 ) ),
   Max_Schadbw_Verkehrssicherheit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Max_Schadbw_Verkehrssicherheit >= 0 ) AND ( Max_Schadbw_Verkehrssicherheit <= 4 ) ),
   Max_Schadbw_Dauerhaftigkeit
      INTEGER, -- Schadensbewertung
   CHECK ( ( Max_Schadbw_Dauerhaftigkeit >= 0 ) AND ( Max_Schadbw_Dauerhaftigkeit <= 4 ) ),
   Datum_naechste_Hauptpruefung
      CHAR(10), -- Datum
   CHECK ( Datum_naechste_Hauptpruefung LIKE '__.__.____' ),
   Art_naechste_Hauptpruefung
      VARCHAR(2),
   Datum_naechste_einf_Pruefung
      CHAR(10), -- Datum
   CHECK ( Datum_naechste_einf_Pruefung LIKE '__.__.____' ),
   Datum_naechste_Sonderpruefung
      CHAR(10), -- Datum
   CHECK ( Datum_naechste_Sonderpruefung LIKE '__.__.____' ),
   Prueftext
      VARCHAR(255),
   Zustandsnote
      REAL
)

CREATE TABLE gegenw_dokum_Empfehlung (
   gegenw_dokum_Empfehlung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (gegenw_dokum_Empfehlung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Art
      VARCHAR(15),
   Menge
      REAL,
   Schaetzkosten
      INTEGER REFERENCES Allgemeine_Objekte.Waehrungsbetrag,
   Schadensbeseitigung
      VARCHAR(15),
   Projektbezeichnung
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255),
   von_gegenw_dok_Bauwerkszustand
      INTEGER NOT NULL REFERENCES gegenw_dokum_Bauwerkszustand
)

CREATE TABLE Empfehlung_abgeschl_Prfg (
   Empfehlung_abgeschl_Prfg_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Empfehlung_abgeschl_Prfg_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Art
      VARCHAR(15),
   Menge
      REAL,
   Schaetzkosten
      INTEGER REFERENCES Allgemeine_Objekte.Waehrungsbetrag,
   Schadensbeseitigung
      VARCHAR(15),
   Projektbezeichnung
      VARCHAR(80),
   Pruefart
      VARCHAR(2),
   Pruefjahr
      INTEGER, -- Jahr
   Bemerkungen
      VARCHAR(255),
   von_abgeschlossene_Pruefung
      INTEGER NOT NULL REFERENCES abgeschlossene_Pruefung
)

CREATE TABLE Prueffahrzeuge_Pruefgeraete (
   Prueffahrzeuge_Pruefgeraete_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Prueffahrzeuge_Pruefgeraete_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Geraeteart
      VARCHAR(15),
   voraussichtl_Einsatzdauer
      INTEGER REFERENCES Allgemeine_Objekte.Dauer,
   Bemerkungen_zu_Prueffahrzeugen
      VARCHAR(255)
)

CREATE TABLE Anlagen_Bauwerksbuch (
   Anlagen_Bauwerksbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Anlagen_Bauwerksbuch_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Beschreibung_sonst_Anlagen
      VARCHAR(255)
)

CREATE TABLE Verwaltungsmassn_Sondervereinb (
   Verwaltungsmassn_Sondervb_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verwaltungsmassn_Sondervb_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Aktenzeichen_des_Verw_Akt
      VARCHAR(30),
   Veranlasser
      VARCHAR(80),
   Wirksamkeitsdatum
      CHAR(10), -- Datum
   CHECK ( Wirksamkeitsdatum LIKE '__.__.____' ),
   Beschreibung_der_Massnahme
      VARCHAR(255)
)

CREATE TABLE Verwmassn_Sonderv__von_Teilbw (
   Verwaltungsmassn_Sondervereinb
      INTEGER NOT NULL REFERENCES Verwaltungsmassn_Sondervereinb,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Bau_und_Erhaltungsmassnahme (
   Bau_und_Erhaltungsmassnahme_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Bau_und_Erhaltungsmassnahme_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Baumassnahme
      VARCHAR(80),
   Art_der_Baumassnahme
      VARCHAR(15),
   Baujahr
      INTEGER, -- Jahr
   Auftragssumme
      INTEGER REFERENCES Allgemeine_Objekte.Waehrungsbetrag,
   Abrechnungssumme
      INTEGER REFERENCES Allgemeine_Objekte.Waehrungsbetrag,
   Auftraggeber_Bau_Erh_Massn
      VARCHAR(80),
   Auftragnehmer_Bau_Erh_Massn
      VARCHAR(80),
   Bauueberwachung
      VARCHAR(80),
   Baubeginn_Bau_Erh_Massn
      CHAR(10), -- Datum
   CHECK ( Baubeginn_Bau_Erh_Massn LIKE '__.__.____' ),
   Bauende_Bau_Erh_Massn
      CHAR(10), -- Datum
   CHECK ( Bauende_Bau_Erh_Massn LIKE '__.__.____' ),
   Ablauf_Maengelanspruch
      CHAR(10), -- Datum
   CHECK ( Ablauf_Maengelanspruch LIKE '__.__.____' ),
   Bemerkungen_Bau_Erh_Massn
      VARCHAR(255)
)

CREATE TABLE Bau_und_Erhmassn__von_Teilbw (
   Bau_und_Erhaltungsmassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Kosten_fuer_Bau_Erh_und_Betr (
   Kosten_f_Bau_Erh_und_Betr_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kosten_f_Bau_Erh_und_Betr_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Kostenart_Bau_Erh_Kosten
      VARCHAR(15),
   Menge_Bau_Erh_Kosten
      FLOAT (12),
   Haushaltsjahr_Bau_Erh_Kosten
      INTEGER, -- Jahr
   Kostentraeger_Bau_Erh_Kosten
      VARCHAR(120),
   Titel_Bau_Erh_Kosten
      VARCHAR(20),
   Ausgabe_Bau_Erh_Kosten
      INTEGER REFERENCES Allgemeine_Objekte.Waehrungsbetrag,
   Bemerkungen
      VARCHAR(255),
   von_Erhaltungs_u_Baumassnahme
      INTEGER NOT NULL REFERENCES Bau_und_Erhaltungsmassnahme
)

CREATE TABLE Ausstattung (
   Ausstattung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Ausstattung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art
      VARCHAR(15),
   Leitungsdurchmesser
      REAL, -- Millimeter
   CHECK ( Leitungsdurchmesser >= 0 ),
   Einbauort
      VARCHAR(255),
   TUEV_Datum
      CHAR(10), -- Datum
   CHECK ( TUEV_Datum LIKE '__.__.____' ),
   Bemerkungen_zu_Ausstattungen
      VARCHAR(255)
)

CREATE TABLE Ausstattung__von_Teilbauwerk (
   Ausstattung
      INTEGER NOT NULL REFERENCES Ausstattung,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Schutzeinrichtungen (
   Schutzeinrichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schutzeinrichtungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_Schutzeinrichtung
      VARCHAR(15),
   Einbauort_Schutzeinrichtung
      VARCHAR(255),
   Einbaujahr_Schutzeinrichtung
      INTEGER, -- Jahr
   Laenge_Schutzeinrichtung
      REAL, -- Meter
   Hoehe_Schutzeinrichtung
      REAL, -- Meter
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Schutzeinr__von_Teilbauwerk (
   Schutzeinrichtungen
      INTEGER NOT NULL REFERENCES Schutzeinrichtungen,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Vorspannungen (
   Vorspannungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Vorspannungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Richtung
      VARCHAR(15),
   intern_extern
      VARCHAR(15),
   Vorspanngrad
      VARCHAR(15),
   Spannverfahren
      VARCHAR(15),
   Spannkraft
      REAL, -- Kilonewton
   CHECK ( Spannkraft >= 0 ),
   Spannstahl_Streckgrenze
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Spannstahl_Streckgrenze >= 0 ),
   Spannstahl_Bruchgrenze
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Spannstahl_Bruchgrenze >= 0 ),
   Spannstahlhersteller
      VARCHAR(15),
   Art_der_Verpressung
      VARCHAR(15),
   Typenbezeichnung
      VARCHAR(80),
   Einbaujahr_Vorspannung
      INTEGER, -- Jahr
   Einbauort_Vorspannung
      VARCHAR(255),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Vorspannungen__von_Teilbauwerk (
   Vorspannungen
      INTEGER NOT NULL REFERENCES Vorspannungen,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Gruendungen (
   Gruendungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gruendungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_der_Gruendungen
      VARCHAR(15),
   Typenbezeichnung_Gruendung
      VARCHAR(80),
   Einbauort_Gruendung
      VARCHAR(255),
   Einbaujahr_Gruendung
      INTEGER, -- Jahr
   Bemerkungen_zur_Gruendung
      VARCHAR(255)
)

CREATE TABLE Gruendungen__von_Teilbauwerk (
   Gruendungen
      INTEGER NOT NULL REFERENCES Gruendungen,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Erd_und_Felsanker (
   Erd_und_Felsanker_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Erd_und_Felsanker_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Verfahren_Erd_und_Felsanker
      VARCHAR(15),
   Hersteller_Erd_und_Felsanker
      VARCHAR(15),
   Zulassungsnummer
      VARCHAR(50),
   Anzahl_Erd_und_Felsanker
      INTEGER,
   Art_Erd_und_Felsanker
      VARCHAR(255),
   Typenbez_Erd_und_Felsanker
      VARCHAR(80),
   Einbauort_Erd_und_Felsanker
      VARCHAR(255),
   Einbaujahr_Erd_und_Felsanker
      INTEGER, -- Jahr
   Bemerkungen_Erd_und_Felsanker
      VARCHAR(255)
)

CREATE TABLE Erd_und_Felsank__von_Teilbauwk (
   Erd_und_Felsanker
      INTEGER NOT NULL REFERENCES Erd_und_Felsanker,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Lager (
   Lager_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Lager_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer_Stuetzung
      VARCHAR(15),
   Anzahl_der_Lager
      INTEGER,
   Art_der_Lager
      VARCHAR(15),
   Typenbezeichnung
      VARCHAR(80),
   Einbauort_der_Lager
      VARCHAR(255),
   Einbaujahr_der_Lager
      INTEGER, -- Jahr
   Hersteller
      VARCHAR(15),
   Kritische_Temperatur_Winter
      REAL, -- Grad_Celsius
   CHECK ( Kritische_Temperatur_Winter >= 0 ),
   Kritische_Temperatur_Sommer
      REAL, -- Grad_Celsius
   CHECK ( Kritische_Temperatur_Sommer >= 0 ),
   Bemerkungen
      VARCHAR(255),
   von_Brueckenfeld_Stuetzung
      INTEGER NOT NULL REFERENCES Brueckenfeld_Stuetzung
)

CREATE TABLE Fahrbahnuebergang (
   Fahrbahnuebergang_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Fahrbahnuebergang_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_Fahrbahnuebergang
      VARCHAR(15),
   Anzahl_Fahrbahnuebergaenge
      INTEGER,
   Anzahl_der_Lamellen
      INTEGER,
   Gesamtdehnweg
      REAL, -- Millimeter
   CHECK ( Gesamtdehnweg >= 0 ),
   Hersteller_Fahrbahnuebergaenge
      VARCHAR(15),
   Typenbez_Fahrbahnuebergaenge
      VARCHAR(80),
   regelgepr_Fahrbahnuebergaenge
      VARCHAR(15),
   Einbauort_Fahrbahnuebergaenge
      VARCHAR(255),
   Einbaujahr_Fahrbahnuebergaenge
      INTEGER, -- Jahr
   Konstruktionslaenge_Uebergang
      REAL, -- Meter
   Wartungsg_Fahrbahnuebergaenge
      VARCHAR(15),
   Kritische_Temperatur_Winter
      REAL, -- Grad_Celsius
   CHECK ( Kritische_Temperatur_Winter >= 0 ),
   Kritische_Temperatur_Sommer
      REAL, -- Grad_Celsius
   CHECK ( Kritische_Temperatur_Sommer >= 0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Fahrbahnuebergang__von_Teilbwk (
   Fahrbahnuebergang
      INTEGER NOT NULL REFERENCES Fahrbahnuebergang,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Kappe (
   Kappe_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kappe_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Einbauort_Kappe
      VARCHAR(255),
   Konstruktion_Kappe
      VARCHAR(15),
   Verankerung_Kappe
      VARCHAR(15),
   groesste_Blocklaenge
      REAL, -- Meter
   Kappenlaenge
      REAL, -- Meter
   Breite_Kappe
      REAL, -- Meter
   Einbaujahr_Kappe
      INTEGER, -- Jahr
   Bemerkungen_zur_Kappe
      VARCHAR(255)
)

CREATE TABLE Kappe__von_Teilbauwerk (
   Kappe
      INTEGER NOT NULL REFERENCES Kappe,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Brueckenseile_und_kabel (
   Brueckenseile_und_kabel_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Brueckenseile_und_kabel_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Seilart
      VARCHAR(15),
   Hersteller
      VARCHAR(15),
   Tragfunktion
      VARCHAR(15),
   Seillaenge
      REAL, -- Meter
   Seildurchmesser
      REAL, -- Millimeter
   CHECK ( Seildurchmesser >= 0 ),
   Seilquerschnitt_metallisch
      REAL, -- Quadratmillimeter
   CHECK ( Seilquerschnitt_metallisch >= 0 ),
   Drahtfestigkeit
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Drahtfestigkeit >= 0 ),
   Seilkraft
      REAL, -- Kilonewton
   CHECK ( Seilkraft >= 0 ),
   Verformungsmodul
      INTEGER, -- Newton_pro_Quadratmillimeter
   CHECK ( Verformungsmodul >= 0 ),
   Schlaglaenge
      REAL, -- Millimeter
   CHECK ( Schlaglaenge >= 0 ),
   Gesamtgewicht
      REAL, -- Tonnen
   CHECK ( Gesamtgewicht >= 0 ),
   Seilverfuellmittel
      VARCHAR(15),
   Seilaufbau
      VARCHAR(15),
   Oberflaechenbeh_des_Drahtes
      VARCHAR(15),
   Oberflaechenbeh_Seilaufbau
      VARCHAR(15),
   Vergusshuelse_Seilkopf
      VARCHAR(15),
   Werkstoff_Vergusshuelse
      VARCHAR(15),
   Seilverguss
      VARCHAR(15),
   Armaturen
      VARCHAR(15),
   schwingungsdaempf_Massnahmen
      VARCHAR(15),
   Bemerkungen_zu_Brueckenseile
      VARCHAR(255)
)

CREATE TABLE Brueckenseile__von_Teilbauwerk (
   Brueckenseile_und_kabel
      INTEGER NOT NULL REFERENCES Brueckenseile_und_kabel,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Abdichtungen (
   Abdichtungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abdichtungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Einbauort_Abdichtungen
      VARCHAR(255),
   Unterlage
      VARCHAR(15),
   Vorbereitung_der_Unterlage
      VARCHAR(15),
   Behandlung_der_Unterlage
      VARCHAR(15),
   Abdichtung
      VARCHAR(15),
   Schutzschicht
      VARCHAR(15),
   Dicke_Schutzschicht
      REAL, -- Zentimeter
   CHECK ( Dicke_Schutzschicht >= 0 ),
   Einbaujahr_Abdichtungen
      INTEGER, -- Jahr
   Flaeche_Abdichtungen
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Abdichtungen >= 0 ),
   Hersteller_Abdichtungen
      VARCHAR(80),
   Ausfuehr_Firma_Abdichtungen
      VARCHAR(80),
   Bemerkungen_zu_Abdichtungen
      VARCHAR(255)
)

CREATE TABLE Abdichtungen__von_Teilbauwerk (
   Abdichtungen
      INTEGER NOT NULL REFERENCES Abdichtungen,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE statisches_System_Tragfaehigkt (
   statisch_Syst_Tragfaehigkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (statisch_Syst_Tragfaehigkt_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   stat_System_in_Bauwerksachse
      VARCHAR(15),
   stat_System_quer_zu_Bauw_achse
      VARCHAR(15),
   Sonderabtragungsrichtung
      VARCHAR(15),
   Ersatzstuetzweite
      FLOAT (7),
   Tragfaehigkeit
      VARCHAR(15),
   Bemessungsfahrzeug_Hauptspur
      REAL, -- Tonnen
   CHECK ( Bemessungsfahrzeug_Hauptspur >= 0 ),
   Bemessungsfahrzeug_Nebenspur
      REAL, -- Tonnen
   CHECK ( Bemessungsfahrzeug_Nebenspur >= 0 ),
   Sperrung_fuer_Schwertransporte
      INTEGER REFERENCES Logical_Types.Boolean,
   statischer_Auslastungsgrad
      REAL, -- Prozent
   Bemessungslast_Kraft
      REAL, -- Kilonewton
   CHECK ( Bemessungslast_Kraft >= 0 ),
   Bemessungslast_Druck
      REAL, -- Kilonewton_pro_Quadratmeter
   CHECK ( Bemessungslast_Druck >= 0 ),
   Einstufungsjahr
      INTEGER, -- Jahr
   Massgeb_Tragfaehigkeitseinstuf
      INTEGER REFERENCES Logical_Types.Boolean,
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE statisch_Sys_Trag__von_Teilbwk (
   statisches_System_Tragfaehigkt
      INTEGER NOT NULL REFERENCES statisches_System_Tragfaehigkt,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Baustoff_Bauwerk (
   Baustoff_Bauwerk_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Baustoff_Bauwerk_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Baustoff
      VARCHAR(15),
   Hauptbaustoff
      INTEGER,
   Festigkeitsklasse_des_Betons
      VARCHAR(15),
   Expositionsklasse
      VARCHAR(80),
   Groesstkorn_Betonzuschlaege
      VARCHAR(15),
   Konsistenz
      VARCHAR(15),
   Baustoffguete_Baustahl
      VARCHAR(15),
   Baustoffguete_Holz
      VARCHAR(15),
   Verbindungsmittel
      VARCHAR(15),
   Zement
      VARCHAR(15),
   Zementgehalt
      REAL, -- Kilogramm_pro_Kubikmeter
   CHECK ( Zementgehalt >= 0 ),
   Betonzuschlag
      VARCHAR(255),
   Betonzusatz
      VARCHAR(255),
   Oberflaeche_des_Betons
      VARCHAR(15),
   Betonstahlguete
      VARCHAR(15),
   Fertigteile
      VARCHAR(15),
   Lieferfirma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255),
   hat_Korrosionsschutzbeschichtg
      INTEGER REFERENCES Korrosionsschutzbeschichtungen,
   von_Ausstattung
      INTEGER REFERENCES Ausstattung,
   von_Brueckenseile_und_kabel
      INTEGER REFERENCES Brueckenseile_und_kabel,
   von_Erd_und_Felsanker
      INTEGER REFERENCES Erd_und_Felsanker,
   von_Fahrbahnuebergang
      INTEGER REFERENCES Fahrbahnuebergang,
   von_Gruendungen
      INTEGER REFERENCES Gruendungen,
   von_Kappe
      INTEGER REFERENCES Kappe,
   von_Lager
      INTEGER REFERENCES Lager,
   von_Schutzeinrichtungen
      INTEGER REFERENCES Schutzeinrichtungen,
   von_Segment_Laermschutzbauwerk
      INTEGER REFERENCES Segment_Laermschutzbauwerk,
   von_Segment_Stuetzbauwerk
      INTEGER REFERENCES Segment_Stuetzbauwerk
)

CREATE TABLE Gestaltungen (
   Gestaltungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gestaltungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_Gestaltung
      VARCHAR(255),
   Einbauort_Gestaltung
      VARCHAR(255),
   Bemerkungen_zur_Gestaltung
      VARCHAR(255)
)

CREATE TABLE Gestaltungen__von_Teilbauwerk (
   Gestaltungen
      INTEGER NOT NULL REFERENCES Gestaltungen,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Leitungen_an_Bauwerken (
   Leitungen_an_Bauwerken_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Leitungen_an_Bauwerken_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Leitungsarten_an_Bauwerken
      VARCHAR(15),
   Einbauort_Leitungen
      VARCHAR(255),
   Durchmesser
      REAL, -- Millimeter
   CHECK ( Durchmesser >= 0 ),
   Betreiber_der_Leitung
      VARCHAR(255),
   Buendelung
      VARCHAR(15),
   Anzahl_der_Leitungen_an_Bw
      INTEGER,
   Nutzungsvereinbarung
      VARCHAR(15),
   Bemerkungen_zu_Leitungen_an_Bw
      VARCHAR(255)
)

CREATE TABLE Leitungen_an_Bwk__von_Teilbwk (
   Leitungen_an_Bauwerken
      INTEGER NOT NULL REFERENCES Leitungen_an_Bauwerken,
   Teilbauwerk_abstrakt
      INTEGER NOT NULL REFERENCES Teilbauwerk_abstrakt
)

CREATE TABLE Verfuellungen (
   Verfuellungen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Verfuellungen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Einbauort_Verfuellung
      VARCHAR(255),
   Schaden_Schadenursache
      VARCHAR(255),
   Fuellgut_Fuellmaterial
      VARCHAR(15),
   Hersteller_Produktbezeichnung
      VARCHAR(15),
   Einbaujahr_Verfuellung
      INTEGER, -- Jahr
   Ausfuehrende_Firma_Verfuellung
      VARCHAR(80),
   Bemerkungen_zur_Verfuellung
      VARCHAR(255)
)

CREATE TABLE Betonersatzsystem (
   Betonersatzsystem_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Betonersatzsystem_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_des_Betonersatzsystems
      VARCHAR(15),
   Einbauort_Betonersatzsystem
      VARCHAR(255),
   Lieferfirma_Produktbezeichnung
      VARCHAR(15),
   Ausfuehrende_Firma_Betonersatz
      VARCHAR(80),
   Bezeichnung_zum_Betonersatz
      VARCHAR(80),
   Einbaujahr_Betonersatzsystem
      INTEGER, -- Jahr
   Flaeche_Betonersatzsystem
      REAL, -- Quadratmeter
   CHECK ( Flaeche_Betonersatzsystem >= 0 ),
   Bemerkungen_zum_Betonersatz
      VARCHAR(255)
)

CREATE TABLE Oberflaechenschutzsystem (
   Oberflaechenschutzsystem_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Oberflaechenschutzsystem_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_des_Systems
      VARCHAR(15),
   Art_der_schuetzenden_Oberfl
      VARCHAR(15),
   Hersteller_Produktbezeichnung
      VARCHAR(15),
   Bezeichnung
      VARCHAR(80),
   Einbauort
      VARCHAR(255),
   Verbrauch
      REAL, -- Kilogramm_pro_Quadratmeter
   CHECK ( Verbrauch >= 0 ),
   Ausfuehrende_Firma
      VARCHAR(80),
   Einbaujahr
      INTEGER, -- Jahr
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche >= 0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Korrosionsschutzbeschichtungen (
   Korrosionsschutzbeschichtgn_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Korrosionsschutzbeschichtgn_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Art_des_Korrosionsschutzes
      VARCHAR(15),
   Bauteiloberflaeche
      VARCHAR(15),
   Oberflaechenvorbereitung
      VARCHAR(15),
   Hauptbindemittel_d_Grundbesch
      VARCHAR(15),
   Hauptpigment_der_Grundbesch
      VARCHAR(15),
   Hauptbindemittel_der_Deckbesch
      VARCHAR(15),
   Hauptpigment_der_Deckbesch
      VARCHAR(15),
   Anzahl_der_Grundbeschichtungen
      INTEGER,
   Anzahl_der_Deckbeschichtungen
      INTEGER,
   Gesamtschichtdicke
      REAL, -- Mikrometer
   CHECK ( Gesamtschichtdicke >= 0 ),
   Applikation
      VARCHAR(15),
   Einbauort_Schutzbeschichtung
      VARCHAR(255),
   Ausfuehrende_Firma_Besch
      VARCHAR(80),
   Bezeichnung_Schutzbeschichtung
      VARCHAR(80),
   Einbaujahr_Korrosionsschutzb
      INTEGER, -- Jahr
   Beschichtete_Flaeche
      REAL, -- Quadratmeter
   CHECK ( Beschichtete_Flaeche >= 0 ),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Reaktionsharzgeb_Duennbelaege (
   Reaktionsharzgeb_Duennbel_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Reaktionsharzgeb_Duennbel_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Bauteilnummer
      VARCHAR(15),
   Einbauort
      VARCHAR(255),
   Vorbereitung_der_Unterlage
      VARCHAR(15),
   Bindemittel_der_Grundierung
      VARCHAR(15),
   Bindemittel_1_u_2_Deckschicht
      VARCHAR(15),
   Abstreumittel_ob_Deckschicht
      VARCHAR(15),
   Gesamtdicke
      REAL, -- Millimeter
   CHECK ( Gesamtdicke >= 0 ),
   Flaeche
      REAL, -- Quadratmeter
   CHECK ( Flaeche >= 0 ),
   Einbaujahr
      INTEGER, -- Jahr
   Ausfuehrende_Firma
      VARCHAR(80),
   Bemerkungen
      VARCHAR(255)
)

CREATE TABLE Tunnelbeleuchtung (
   Tunnelbeleuchtung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnelbeleuchtung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Lichtraster
      VARCHAR(15),
   Leuchtdichte
      INTEGER, -- cd_pro_Quadratmeter
   CHECK ( Leuchtdichte >= 0 ),
   Beleuchtungsstaerke
      INTEGER, -- Lux
   CHECK ( Beleuchtungsstaerke >= 0 ),
   Beleuchtungsart
      VARCHAR(15),
   Lampenart
      VARCHAR(15),
   Bemerkungen_zur_Tunnelbeleucht
      VARCHAR(255)
)

CREATE TABLE Tunnellueftung (
   Tunnellueftung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnellueftung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Lueftungsart_Normalbetrieb
      VARCHAR(15),
   Lueftungsart_Brandfall
      VARCHAR(15),
   Abluftkanaele
      VARCHAR(15),
   Zuluftkanaele
      VARCHAR(15),
   Abluftkamin
      VARCHAR(15),
   Luefterdecke
      VARCHAR(15),
   Bemerkungen_zur_Tunnellueftung
      VARCHAR(255)
)

CREATE TABLE Tunnelsicherheit (
   Tunnelsicherheit_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnelsicherheit_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Gefahrengueter_zugelassen
      VARCHAR(15),
   Pannenbucht
      VARCHAR(15),
   Anzahl_Pannenbuchten
      INTEGER,
   Abstand_Pannenbucht
      REAL, -- Meter
   Wendebucht
      VARCHAR(15),
   Anzahl_Wendebuchten
      INTEGER,
   Abstand_Wendebucht
      REAL, -- Meter
   Ueberfahrt
      VARCHAR(15),
   Anzahl_Ueberfahrten
      INTEGER,
   Abstand_Ueberfahrt
      REAL, -- Meter
   Notrufstation
      VARCHAR(15),
   Anzahl_Notrufstationen
      INTEGER,
   Abstand_Notrufstation
      REAL, -- Meter
   Automatische_Brandmeldeanlagen
      VARCHAR(15),
   Feuerloeschstationen
      VARCHAR(15),
   Anzahl_Feuerloeschstationen
      INTEGER,
   Abstand_Feuerloeschstation
      REAL, -- Meter
   Hydranten
      VARCHAR(15),
   Anzahl_Hydranten
      INTEGER,
   Abstand_Hydranten
      REAL, -- Meter
   Fluchtwege_Querstollen
      VARCHAR(15),
   Anzahl_Fluchtwege_Querstollen
      INTEGER,
   Abstand_Fluchtwege_Querstollen
      REAL, -- Meter
   Fluchtwege_Fluchtstollen
      VARCHAR(15),
   Anzahl_Fluchtwege_Fluchtstoll
      INTEGER,
   Abstand_Fluchtwege_Fluchtstoll
      REAL, -- Meter
   Videoueberwachung
      VARCHAR(15),
   Funk
      VARCHAR(15),
   Lautsprecher
      VARCHAR(15),
   Bemerkungen_zur_Tunnelsicherh
      VARCHAR(255)
)

CREATE TABLE Tunnel_Verkehrseinrichtungen (
   Tunnel_Verkehrseinrichtung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnel_Verkehrseinrichtung_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   Verkehrseinrichtung_vorhanden
      VARCHAR(15),
   Verkehrserfassung
      VARCHAR(15),
   LZA_vor_dem_Tunnel
      VARCHAR(15),
   Wechselverk_Zeich_v_d_Tunnel
      VARCHAR(15),
   Wechselverk_Zeichen_im_Tunnel
      VARCHAR(15),
   Fahrstreifensignale
      VARCHAR(15),
   Schrankenanlage
      VARCHAR(15),
   Bemerkungen_zu_Verkehrseinr
      VARCHAR(255)
)

CREATE TABLE Tunnel_Zentrale_Anlagen (
   Tunnel_Zentrale_Anlagen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Tunnel_Zentrale_Anlagen_ID) REFERENCES Allgemeine_Objekte.Objekt_mit_ID,
   gesamte_elektrische_Leistung
      INTEGER, -- Kilowatt
   CHECK ( gesamte_elektrische_Leistung >= 0 ),
   Ersatzstromversorgung
      VARCHAR(15),
   Ersatzstromversorgung_Leistung
      INTEGER, -- Kilowatt
   CHECK ( Ersatzstromversorgung_Leistung >= 0 ),
   Betriebsgebaeude
      VARCHAR(15),
   Betriebsgebaeude_Anzahl
      INTEGER,
   Lueftergebaeude
      VARCHAR(15),
   Lueftergebaeude_Anzahl
      INTEGER,
   Hebeanlage
      VARCHAR(15),
   Bemerkungen_zu_zentr_Anlagen
      VARCHAR(255)
)

