CREATE SCHEMA Allgemeine_Geometrieobjekte

-- Historie:
--
-- 02.08.2006 - 1.011
-- Einfhrung OKSTRA-ID gem N0073
--
-- 09.09.2005 - 1.010 (1.010)
-- Einfhrung von OKSTRA-Text gem Dokument N0068
-- berarbeitung gem Dokument N0067
--
-- 29.06.2004 - 1.004 (1.009)
-- berarbeitung gem Dokument N0060
--
-- 03.09.2003 - 1.003 (1.008)
-- berarbeitung gem Dokument N0051
--
-- 31.05.2002 - 1.002 (1.007)
-- berarbeitung gem Dokument N0030
--
-- 12.09.2001 - 1.001 (1.004)
-- berarbeitung in Folge des nderungsantrags A0006
-- ALKIS-Objekte in neues Schema Kataster verlegt
--
-- 09.10.1999 - 1.000 (1.001)
-- Modellierung erstellt

CREATE TABLE allgemeines_Punktobjekt (
   allgemeines_Punktobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (allgemeines_Punktobjekt_ID) REFERENCES DGM_Punkt,
   FOREIGN KEY (allgemeines_Punktobjekt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften
)

CREATE TABLE Symbol (
   Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Symbol_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Symbolbedeutung
      VARCHAR(255) NOT NULL,
   Breite_links
      REAL NOT NULL, -- Groesse
   CHECK ( Breite_links >= 0 ),
   Breite_rechts
      REAL NOT NULL, -- Groesse
   CHECK ( Breite_rechts >= 0 ),
   Hoehe_oben
      REAL NOT NULL, -- Groesse
   CHECK ( Hoehe_oben >= 0 ),
   Hoehe_unten
      REAL NOT NULL, -- Groesse
   CHECK ( Hoehe_unten >= 0 ),
   Einheit
      INTEGER NOT NULL REFERENCES Einheit,
   Drehwinkel
      REAL NOT NULL, -- Winkel
   mit_Bezug_auf_allg_Punktobjekt
      INTEGER NOT NULL REFERENCES allgemeines_Punktobjekt
)

CREATE TABLE Einheit (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(4) NOT NULL
)

INSERT INTO Einheit VALUES (0,'Welt')
INSERT INTO Einheit VALUES (1,'mm')

CREATE TABLE allgemeines_Linienobjekt (
   allgemeines_Linienobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (allgemeines_Linienobjekt_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (allgemeines_Linienobjekt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften
)

CREATE TABLE allgemeines_Flaechenobjekt (
   allgemeines_Flaechenobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (allgemeines_Flaechenobjekt_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   FOREIGN KEY (allgemeines_Flaechenobjekt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften
)

CREATE TABLE Dreieck (
   Dreieck_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Dreiecksnummer
      INTEGER NOT NULL,
   Dreiecksbedeutung
      VARCHAR(255),
   in_DGM
      INTEGER NOT NULL REFERENCES Entwurf.DGM
)

CREATE TABLE Dreieck__hat_Punkte (
   Dreieck
      INTEGER NOT NULL REFERENCES Dreieck,
   DGM_Punkt
      INTEGER NOT NULL REFERENCES DGM_Punkt,
   folgt_auf_DGM_Punkt
      INTEGER REFERENCES DGM_Punkt
)

CREATE TABLE Dreieck__hat_Seiteneigensch (
   Dreieck
      INTEGER NOT NULL REFERENCES Dreieck,
   Seiteneigenschaft
      INTEGER NOT NULL REFERENCES Seiteneigenschaft,
   folgt_auf_Seiteneigenschaft
      INTEGER REFERENCES Seiteneigenschaft
)

CREATE TABLE DGM_Punkt (
   DGM_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (DGM_Punkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell
)

CREATE TABLE Seiteneigenschaft (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(13) NOT NULL
)

INSERT INTO Seiteneigenschaft VALUES (1,'normale Seite')
INSERT INTO Seiteneigenschaft VALUES (2,'Bruchlinie')
INSERT INTO Seiteneigenschaft VALUES (3,'Formlinie')

CREATE TABLE Beschriftung (
   Beschriftung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Beschriftung_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Text
      VARCHAR(255) NOT NULL,
   Textbedeutung
      VARCHAR(255) NOT NULL,
   Drehwinkel
      REAL NOT NULL, -- Winkel
   zu_Punktobjekt_Modell
      INTEGER REFERENCES Geometrieschema.Punktobjekt_Modell,
   hat_Textausgestaltung
      INTEGER REFERENCES Textausgestaltung
)

CREATE TABLE Textausgestaltung (
   Textausgestaltung_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Breite
      REAL NOT NULL, -- Groesse
   CHECK ( Breite >= 0 ),
   Hoehe
      REAL NOT NULL, -- Groesse
   CHECK ( Hoehe >= 0 ),
   Einheit
      INTEGER NOT NULL REFERENCES Einheit,
   Schriftart
      VARCHAR(255) NOT NULL,
   Schrifthoehe
      REAL NOT NULL, -- Groesse
   CHECK ( Schrifthoehe >= 0 ),
   Schriftfarbe
      INTEGER NOT NULL REFERENCES RGB_Farbe,
   Kasten
      INTEGER NOT NULL REFERENCES Logical_Types.Boolean,
   Beschriftungsfahne
      INTEGER REFERENCES Beschriftungsfahne,
   vertikale_Ausrichtung
      INTEGER NOT NULL REFERENCES vertikale_Ausrichtung,
   horizontale_Ausrichtung
      INTEGER NOT NULL REFERENCES horizontale_Ausrichtung,
   Einfuegeposition
      INTEGER NOT NULL REFERENCES Einfuegeposition
)

CREATE TABLE Einfuegeposition (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(17) NOT NULL
)

INSERT INTO Einfuegeposition VALUES (1, 'Ecke oben links')
INSERT INTO Einfuegeposition VALUES (2, 'Mitte oben')
INSERT INTO Einfuegeposition VALUES (3, 'Ecke oben rechts')
INSERT INTO Einfuegeposition VALUES (4, 'Mitte links')
INSERT INTO Einfuegeposition VALUES (5, 'Mitte')
INSERT INTO Einfuegeposition VALUES (6, 'Mitte rechts')
INSERT INTO Einfuegeposition VALUES (7, 'Ecke unten links')
INSERT INTO Einfuegeposition VALUES (8, 'Mitte unten')
INSERT INTO Einfuegeposition VALUES (9, 'Ecke unten rechts')

CREATE TABLE RGB_Farbe (
   RGB_Farbe_ID
      INTEGER NOT NULL PRIMARY KEY,
   OKSTRA_ID
      CHAR(32), -- GUID
   Farbwert_rot
      INTEGER NOT NULL, -- RGB_Farbwert
   CHECK ( ( Farbwert_rot >= 0 ) AND ( Farbwert_rot <= 255 ) ),
   Farbwert_gruen
      INTEGER NOT NULL, -- RGB_Farbwert
   CHECK ( ( Farbwert_gruen >= 0 ) AND ( Farbwert_gruen <= 255 ) ),
   Farbwert_blau
      INTEGER NOT NULL, -- RGB_Farbwert
   CHECK ( ( Farbwert_blau >= 0 ) AND ( Farbwert_blau <= 255 ) )
)

CREATE TABLE Beschriftungsfahne (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(8) NOT NULL
)

INSERT INTO Beschriftungsfahne VALUES (1,'gerade')
INSERT INTO Beschriftungsfahne VALUES (2,'geknickt')

CREATE TABLE vertikale_Ausrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(9) NOT NULL
)

INSERT INTO vertikale_Ausrichtung VALUES (0,'zentriert')
INSERT INTO vertikale_Ausrichtung VALUES (1,'oben')
INSERT INTO vertikale_Ausrichtung VALUES (2,'unten')

CREATE TABLE horizontale_Ausrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(13) NOT NULL
)

INSERT INTO horizontale_Ausrichtung VALUES (0,'zentriert')
INSERT INTO horizontale_Ausrichtung VALUES (1,'linksbuendig')
INSERT INTO horizontale_Ausrichtung VALUES (2,'rechtsbuendig')

